@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 ############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2013 AKFish <akfish@gmail.com>                                     #
@@ -90,7 +88,7 @@ DEFAULT_TIMEOUT = 15
 DEFAULT_PER_PAGE = 30
 
 
-class Github(object):
+class Github:
     """
     This is the main class you instantiate to access the Github API v3. Optional parameters allow different authentication methods.
     """
@@ -339,13 +337,13 @@ class Github(object):
         """
         assert isinstance(full_name_or_id, (str, int)), full_name_or_id
         url_base = "/repositories/" if isinstance(full_name_or_id, int) else "/repos/"
-        url = "%s%s" % (url_base, full_name_or_id)
+        url = f"{url_base}{full_name_or_id}"
         if lazy:
             return Repository.Repository(
                 self.__requester, {}, {"url": url}, completed=False
             )
         headers, data = self.__requester.requestJsonAndCheck(
-            "GET", "%s%s" % (url_base, full_name_or_id)
+            "GET", f"{url_base}{full_name_or_id}"
         )
         return Repository.Repository(self.__requester, headers, data, completed=True)
 
@@ -431,7 +429,7 @@ class Github(object):
         query,
         sort=github.GithubObject.NotSet,
         order=github.GithubObject.NotSet,
-        **qualifiers
+        **qualifiers,
     ):
         """
         :calls: `GET /search/repositories <http://developer.github.com/v3/search>`_
@@ -459,7 +457,7 @@ class Github(object):
             query_chunks.append(query)
 
         for qualifier, value in qualifiers.items():
-            query_chunks.append("%s:%s" % (qualifier, value))
+            query_chunks.append(f"{qualifier}:{value}")
 
         url_parameters["q"] = " ".join(query_chunks)
         assert url_parameters["q"], "need at least one qualifier"
@@ -476,7 +474,7 @@ class Github(object):
         query,
         sort=github.GithubObject.NotSet,
         order=github.GithubObject.NotSet,
-        **qualifiers
+        **qualifiers,
     ):
         """
         :calls: `GET /search/users <http://developer.github.com/v3/search>`_
@@ -500,7 +498,7 @@ class Github(object):
             query_chunks.append(query)
 
         for qualifier, value in qualifiers.items():
-            query_chunks.append("%s:%s" % (qualifier, value))
+            query_chunks.append(f"{qualifier}:{value}")
 
         url_parameters["q"] = " ".join(query_chunks)
         assert url_parameters["q"], "need at least one qualifier"
@@ -517,7 +515,7 @@ class Github(object):
         query,
         sort=github.GithubObject.NotSet,
         order=github.GithubObject.NotSet,
-        **qualifiers
+        **qualifiers,
     ):
         """
         :calls: `GET /search/issues <http://developer.github.com/v3/search>`_
@@ -541,7 +539,7 @@ class Github(object):
             query_chunks.append(query)
 
         for qualifier, value in qualifiers.items():
-            query_chunks.append("%s:%s" % (qualifier, value))
+            query_chunks.append(f"{qualifier}:{value}")
 
         url_parameters["q"] = " ".join(query_chunks)
         assert url_parameters["q"], "need at least one qualifier"
@@ -556,7 +554,7 @@ class Github(object):
         sort=github.GithubObject.NotSet,
         order=github.GithubObject.NotSet,
         highlight=False,
-        **qualifiers
+        **qualifiers,
     ):
         """
         :calls: `GET /search/code <http://developer.github.com/v3/search>`_
@@ -585,7 +583,7 @@ class Github(object):
             query_chunks.append(query)
 
         for qualifier, value in qualifiers.items():
-            query_chunks.append("%s:%s" % (qualifier, value))
+            query_chunks.append(f"{qualifier}:{value}")
 
         url_parameters["q"] = " ".join(query_chunks)
         assert url_parameters["q"], "need at least one qualifier"
@@ -605,7 +603,7 @@ class Github(object):
         query,
         sort=github.GithubObject.NotSet,
         order=github.GithubObject.NotSet,
-        **qualifiers
+        **qualifiers,
     ):
         """
         :calls: `GET /search/commits <http://developer.github.com/v3/search>`_
@@ -633,7 +631,7 @@ class Github(object):
             query_chunks.append(query)
 
         for qualifier, value in qualifiers.items():
-            query_chunks.append("%s:%s" % (qualifier, value))
+            query_chunks.append(f"{qualifier}:{value}")
 
         url_parameters["q"] = " ".join(query_chunks)
         assert url_parameters["q"], "need at least one qualifier"
@@ -661,7 +659,7 @@ class Github(object):
             query_chunks.append(query)
 
         for qualifier, value in qualifiers.items():
-            query_chunks.append("%s:%s" % (qualifier, value))
+            query_chunks.append(f"{qualifier}:{value}")
 
         url_parameters["q"] = " ".join(query_chunks)
         assert url_parameters["q"], "need at least one qualifier"
@@ -809,7 +807,7 @@ class Github(object):
             return GithubApp.GithubApp(self.__requester, headers, data, completed=True)
 
 
-class GithubIntegration(object):
+class GithubIntegration:
     """
     Main class to obtain tokens for a GitHub integration.
     """
@@ -858,7 +856,7 @@ class GithubIntegration(object):
                 self.base_url, installation_id
             ),
             headers={
-                "Authorization": "Bearer {}".format(self.create_jwt()),
+                "Authorization": f"Bearer {self.create_jwt()}",
                 "Accept": Consts.mediaTypeIntegrationPreview,
                 "User-Agent": "PyGithub/Python",
             },
@@ -892,13 +890,13 @@ class GithubIntegration(object):
         :rtype: :class:`github.Installation.Installation`
         """
         headers = {
-            "Authorization": "Bearer {}".format(self.create_jwt()),
+            "Authorization": f"Bearer {self.create_jwt()}",
             "Accept": Consts.mediaTypeIntegrationPreview,
             "User-Agent": "PyGithub/Python",
         }
 
         response = requests.get(
-            "{}/repos/{}/{}/installation".format(self.base_url, owner, repo),
+            f"{self.base_url}/repos/{owner}/{repo}/installation",
             headers=headers,
         )
         response_dict = response.json()
