@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 ############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2018 bbi-yggy <yossarian@blackbirdinteractive.com>                 #
@@ -168,7 +166,9 @@ class ProjectCard(github.GithubObject.CompletableGithubObject):
         :rtype: bool
         """
         status, _, _ = self._requester.requestJson(
-            "DELETE", self.url, headers={"Accept": Consts.mediaTypeProjectsPreview},
+            "DELETE",
+            self.url,
+            headers={"Accept": Consts.mediaTypeProjectsPreview},
         )
         return status == 204
 
