@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 ############################ Copyrights and license ############################
 #                                                                              #
 # Copyright 2013 Vincent Jacques <vincent@vincent-jacques.net>                 #
@@ -26,8 +24,6 @@
 #                                                                              #
 ################################################################################
 
-from __future__ import absolute_import
-
 import github.GithubObject
 
 
